@@ -143,9 +143,9 @@ lstAccessor <- function(resType){
          "routes"              =  "[[c('routes')]]",
          "legs"                =  "[[c('routes','legs')]][[1]]",
          "steps"               =  "[[c('routes','legs')]][[1]][['steps']][[1]]",
-         "polints"             =  "[[c('routes','legs')]][[1]][['steps']][[1]][[c('polyline','points')]]",
+         "points"              =  "[[c('routes','legs')]][[1]][['steps']]",
          "polyline"            =  "[[c('routes','overview_polyline','points')]]",
-         "instructions"        =  "[[c('routes','legs')]][[1]][['steps']][[1]][['html_instructions']]",
+         "instructions"        =  "[[c('routes','legs')]][[1]][['steps']]",
          "coordinates"         =  "[[c('results','geometry','location')]]",
          "address"             =  "[[c('results','formatted_address')]]",
          "address_components"  =  "[[c('results','address_components')]][[1]]",
