@@ -8,9 +8,12 @@ HTMLWidgets.widget({
         return {
             renderValue: function (x) {
 
-                window.params = [];
-                window.params.push({'map_id' : el.id });
-                window.params.push({'event_return_type' : x.event_return_type});
+                //console.log( x ) ;
+                window.googleway = [];
+                window.googleway.params = [];
+                window.googleway.params.push({'map_id' : el.id });
+                window.googleway.params.push({'event_return_type' : x.event_return_type});
+                //console.log( window.googleway.params );
 
                 // visualisation layers
                 window[el.id + 'googleTrafficLayer'] = [];
@@ -24,8 +27,8 @@ HTMLWidgets.widget({
                     //console.log("search box");
                     // create a place DOM element
                     window[el.id + 'googleSearchBox'] = document.createElement("input");
-                    window[el.id + 'googleSearchBox'].setAttribute('id', 'pac-input');
-                    window[el.id + 'googleSearchBox'].setAttribute('class', 'controls');
+                    window[el.id + 'googleSearchBox'].setAttribute('id', el.id+'pac-input');
+                    window[el.id + 'googleSearchBox'].setAttribute('class', 'pac-input');
                     window[el.id + 'googleSearchBox'].setAttribute('type', 'text');
                     window[el.id + 'googleSearchBox'].setAttribute('placeholder', 'Search location');
                     document.body.appendChild(window[el.id + 'googleSearchBox']);
@@ -59,8 +62,9 @@ HTMLWidgets.widget({
 
                         if(x.split_view !== null) {
 
-                          //console.log("split view");
-                          //console.log(x.split_view_options);
+                          console.log("split view");
+                          console.log(x.split_view);
+                          console.log(x.split_view_options);
 
                             var panorama = new google.maps.StreetViewPanorama(
                                 document.getElementById(x.split_view), {
@@ -73,14 +77,16 @@ HTMLWidgets.widget({
                                       }
                                 });
 
-                            map.setStreetView(panorama);
+                            map.setStreetView( panorama );
+
+                            window[ el.id + x.split_view ] = panorama;
                         }
 
 
                         //global map object
                         window[el.id + 'map'] = map;
 
-                        if (google !== undefined) {
+                        if (google !== undefined && google.charts !== undefined ) {
                             //console.log("exists");
                             clearInterval(checkExists);
 
@@ -118,6 +124,39 @@ HTMLWidgets.widget({
 });
 
 
+function update_pano( map_id, pano, lat, lon ) {
+
+
+  var pano = window[ map_id + pano];
+  var map = window[ map_id + 'map'];
+  //var center = map.getCenter();
+  var center = {lat: lat, lng: lon};
+
+  //console.log( pano );
+  pano.setPosition( center );
+  //console.log( pano );
+
+  window[ map_id + 'map'].setStreetView( pano );
+
+/*
+  var panorama = new google.maps.StreetViewPanorama(
+      document.getElementById( pano ), {
+          position: {lat: center.lat(), lng: center.lng() },
+          pov: {
+          //    heading: location.heading,
+          //    pitch: location.pitch
+              heading: 34,
+              pitch: 10
+             }
+      });
+*/
+
+
+  //map.setStreetView( panorama );
+  //window[ map_id + 'map'].setStreetView( panorama );
+}
+
+
 
 if (HTMLWidgets.shinyMode) {
 
@@ -156,7 +195,6 @@ if (HTMLWidgets.shinyMode) {
 }
 
 
-
 /**
  * Updates the google map with a particular style
  * @param map_id
@@ -233,7 +271,7 @@ function initialise_map(el, x) {
 
     // if places
     if (x.search_box === true) {
-        input = document.getElementById('pac-input');
+        input = document.getElementById(el.id+'pac-input');
 
         window[el.id + 'googleSearchBox'] = new google.maps.places.SearchBox(input);
         window[el.id + 'map'].controls[google.maps.ControlPosition.TOP_LEFT].push(input);
@@ -299,7 +337,7 @@ function initialise_map(el, x) {
 
                 if (HTMLWidgets.shinyMode) {
 
-                    event_return_type = window.params[1].event_return_type,
+                    event_return_type = window.googleway.params[1].event_return_type,
                         eventInfo = {
                             address_components: place.address_components,
                             lat: place.geometry.location.lat(),
@@ -312,6 +350,7 @@ function initialise_map(el, x) {
                         };
 
                     eventInfo = event_return_type === "list" ? eventInfo : JSON.stringify(eventInfo);
+
                     Shiny.onInputChange(el.id + "_place_search", eventInfo);
                 }
 
@@ -342,6 +381,10 @@ function initialise_map(el, x) {
         }
     }
 
+    if( x.geolocation === true) {
+        add_geolocation();
+    }
+
     // listeners
     mapInfo = {};
     map_click(el.id, window[el.id + 'map'], mapInfo);
@@ -455,15 +498,15 @@ function removeControl(map_id, legend_id, position) {
 
 function clearControl(control, legend_id) {
 
-    if (control != null) {
-        control.forEach(function (item, index) {
-            if (item != null) {
-                if (item.getAttribute('id') === legend_id) {
-                    control.removeAt(index);
-                }
-            }
-        });
-    }
+  if (control != null) {
+    control.forEach(function (item, index) {
+      if (item != null) {
+        if (item.getAttribute('id') === legend_id) {
+          control.removeAt(index);
+        }
+      }
+    });
+  }
 }
 
 /**
@@ -472,22 +515,22 @@ function clearControl(control, legend_id) {
 */
 function clear_object(map_id, objType, layer_id) {
 
-    var i = 0;
-    if (window[map_id + objType + layer_id] && window[map_id + objType + layer_id].length) {
-        for (i = 0; i < window[map_id + objType + layer_id].length; i++) {
-            //https://developers.google.com/maps/documentation/javascript/reference/3/#event
-            google.maps.event.clearInstanceListeners(window[map_id + objType + layer_id][i]);
-            window[map_id + objType + layer_id][i].setMap(null);
-            window[map_id + objType + layer_id][i] = null;
-        }
-        window[map_id + objType + layer_id] = null;
+  var i = 0;
+  if (window[map_id + objType + layer_id] && window[map_id + objType + layer_id].length) {
+    for (i = 0; i < window[map_id + objType + layer_id].length; i++) {
+    //https://developers.google.com/maps/documentation/javascript/reference/3/#event
+    google.maps.event.clearInstanceListeners(window[map_id + objType + layer_id][i]);
+    window[map_id + objType + layer_id][i].setMap(null);
+    window[map_id + objType + layer_id][i] = null;
+  }
+  window[map_id + objType + layer_id] = null;
 
-        clear_legend(map_id, layer_id);
-    }
+  clear_legend(map_id, layer_id);
+  }
 }
 
 function delay(t, v) {
-    return new Promise(function(resolve) {
-        setTimeout(resolve.bind(null, v), t)
-    });
+  return new Promise(function(resolve) {
+    setTimeout(resolve.bind(null, v), t);
+  });
 }
